@@ -19,10 +19,8 @@ import (
 )
 
 const (
-	v4localnetGatewayIP = "169.254.33.2"
-
 	// localnetGatewayNextHopPort is the name of the gateway port on the host to which all
-	// the packets leaving the OVN logical topology will be forwarded
+	// the packets leaving/entering the OVN logical topology to the host will egress for shared gw mode
 	localnetGatewayNextHopPort = "ovn-k8s-gw0"
 
 	// Routing table for ExternalIP communication
@@ -91,6 +89,8 @@ func (npw *localPortWatcherData) addService(svc *kapi.Service) error {
 	if isIPv6Service {
 		gatewayIP = npw.gatewayIPv6
 	}
+	// holds map of external ips and if they are currently using routes
+	routeUsage := make(map[string]bool)
 	for _, port := range svc.Spec.Ports {
 		if util.ServiceTypeHasNodePort(svc) {
 			if err := util.ValidatePort(port.Protocol, port.NodePort); err != nil {
@@ -137,11 +137,7 @@ func (npw *localPortWatcherData) addService(svc *kapi.Service) error {
 				klog.V(5).Infof("ExternalIP: %s is reachable through one of the interfaces on this node, will skip setup", externalIP)
 			} else {
 				if gatewayIP != "" {
-					if stdout, stderr, err := util.RunIP("route", "replace", externalIP, "via", gatewayIP, "dev", localnetGatewayNextHopPort, "table", localnetGatewayExternalIDTable); err != nil {
-						klog.Errorf("Error adding routing table entry for ExternalIP %s: stdout: %s, stderr: %s, err: %v", externalIP, stdout, stderr, err)
-					} else {
-						klog.V(5).Infof("Successfully added route for ExternalIP: %s", externalIP)
-					}
+					routeUsage[externalIP] = true
 				} else {
 					klog.Warningf("No gateway of appropriate IP family for ExternalIP %s for Service %s/%s",
 						externalIP, svc.Namespace, svc.Name)
@@ -149,6 +145,13 @@ func (npw *localPortWatcherData) addService(svc *kapi.Service) error {
 			}
 		}
 	}
+	for externalIP := range routeUsage {
+		if stdout, stderr, err := util.RunIP("route", "replace", externalIP, "via", gatewayIP, "dev", util.K8sMgmtIntfName, "table", localnetGatewayExternalIDTable); err != nil {
+			klog.Errorf("Error adding routing table entry for ExternalIP %s, via gw: %s: stdout: %s, stderr: %s, err: %v", externalIP, gatewayIP, stdout, stderr, err)
+		} else {
+			klog.V(5).Infof("Successfully added route for ExternalIP: %s", externalIP)
+		}
+	}
 	klog.V(5).Infof("Adding iptables rules: %v for service: %v", iptRules, svc.Name)
 	return addIptRules(iptRules)
 }
@@ -160,6 +163,8 @@ func (npw *localPortWatcherData) deleteService(svc *kapi.Service) error {
 	if isIPv6Service {
 		gatewayIP = npw.gatewayIPv6
 	}
+	// holds map of external ips and if they are currently using routes
+	routeUsage := make(map[string]bool)
 	// Note that unlike with addService we just silently ignore IPv4/IPv6 mismatches here
 	for _, port := range svc.Spec.Ports {
 		if util.ServiceTypeHasNodePort(svc) {
@@ -183,15 +188,20 @@ func (npw *localPortWatcherData) deleteService(svc *kapi.Service) error {
 				klog.V(5).Infof("ExternalIP: %s is reachable through one of the interfaces on this node, will skip cleanup", externalIP)
 			} else {
 				if gatewayIP != "" {
-					if stdout, stderr, err := util.RunIP("route", "del", externalIP, "via", gatewayIP, "dev", localnetGatewayNextHopPort, "table", localnetGatewayExternalIDTable); err != nil {
-						klog.Errorf("Error delete routing table entry for ExternalIP %s: stdout: %s, stderr: %s, err: %v", externalIP, stdout, stderr, err)
-					} else {
-						klog.V(5).Infof("Successfully deleted route for ExternalIP: %s", externalIP)
-					}
+					routeUsage[externalIP] = true
 				}
 			}
 		}
 	}
+
+	for externalIP := range routeUsage {
+		if stdout, stderr, err := util.RunIP("route", "del", externalIP, "via", gatewayIP, "dev", util.K8sMgmtIntfName, "table", localnetGatewayExternalIDTable); err != nil {
+			klog.Errorf("Error delete routing table entry for ExternalIP %s: stdout: %s, stderr: %s, err: %v", externalIP, stdout, stderr, err)
+		} else {
+			klog.V(5).Infof("Successfully deleted route for ExternalIP: %s", externalIP)
+		}
+	}
+
 	klog.V(5).Infof("Deleting iptables rules: %v for service: %v", iptRules, svc.Name)
 	return delIptRules(iptRules)
 }
@@ -200,7 +210,8 @@ func (npw *localPortWatcherData) syncServices(serviceInterface []interface{}) {
 	removeStaleRoutes := func(keepRoutes []string) {
 		stdout, stderr, err := util.RunIP("route", "list", "table", localnetGatewayExternalIDTable)
 		if err != nil || stdout == "" {
-			klog.Infof("No routing table entries for ExternalIP table %s: stdout: %s, stderr: %s, err: %v", localnetGatewayExternalIDTable, stdout, stderr, err)
+			klog.Infof("No routing table entries for ExternalIP table %s: stdout: %s, stderr: %s, err: %v",
+				localnetGatewayExternalIDTable, stdout, strings.Replace(stderr, "\n", "", -1), err)
 			return
 		}
 		for _, existingRoute := range strings.Split(stdout, "\n") {
